import { View } from "tns-core-modules/ui/core/view";

function toIOSValue(jsValue: any) {
    let returnVal: any = "null";

    if (jsValue !== null) {
        switch (typeof jsValue) {
            case "object":
                returnVal = JSON.stringify(jsValue);
                break;
            case "boolean":
            case "number":
            case "string":
                returnVal = jsValue;
                break;
            default:
                console.log(`Unhandled type: ${typeof jsValue}`);
                break;
        }
    }

    return returnVal;
}

function toNsdictinary(obj : any) {
	const dictionary = NSMutableDictionary.new();
	if(obj === undefined) {
		return dictionary;
	}

	for (const property in obj) {
        if (obj.hasOwnProperty(property)) {
            let value = obj[property];
            if (value === null || value === undefined) {
                dictionary.setObjectForKey("null", property);
            } else {
                dictionary.setObjectForKey(toIOSValue(value), property);
            }
        }
    }

    return dictionary;
}

export const start = function(reportUrl: string, appid: string, isInternalMode = false) {
	if(reportUrl === undefined || appid == undefined) {
		return false;
	}

	if(typeof(Storyboard) !== "undefined") {
		let errorRef = new interop.Reference();
		let settings = GLAStartupSettings.settings();
		settings.reportUrl = reportUrl;
		settings.appId = appid;
		if(isInternalMode) {
			settings.configuraiton = GLAConfigurationType.GLAConfigurationInternal;
		} else {
			settings.configuraiton = GLAConfigurationType.GLAConfigurationExternal;
		}

		Storyboard.startError(settings, null);
	}

	return true;
}

export const stop = function() {
	if(typeof(Storyboard) !== "undefined") {
		Storyboard.stop();
	}
}

export const startScreen = function(screenName: string) {
	if(typeof(Storyboard) !== "undefined") {
		Storyboard.startScreen(screenName);
	}
}

export const endScreen = function() {
	if(typeof(Storyboard) !== "undefined") {
		Storyboard.endScreen();
	}
}

export const reportEvent = function(eventName: string, parameters: any) {
	if(typeof(Storyboard) !== "undefined") {
		Storyboard.reportEventParameters(eventName, toNsdictinary(parameters));
	}
}

export const setViewAsSensitive = function(view: View) {
	if(typeof(Storyboard) !== "undefined") {
		Storyboard.hideSensitiveView(view.nativeView.nativeViewProtected);
	}
}