package com.storyboard;

import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableMapKeySetIterator;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

class ModuleHelpers {
	// taken from https://github.com/facebook/react-native/blob/master/ReactAndroid/src/main/java/com/facebook/react/bridge/ReadableNativeMap.java
	// with slight modification
	static Map<String, Object> toMap(ReadableMap readableMap) {
		ReadableMapKeySetIterator iterator = readableMap.keySetIterator();
		Map<String, Object> hashMap = new HashMap<>();
		while (iterator.hasNextKey()) {
			String key = iterator.nextKey();
			switch (readableMap.getType(key)) {
				case Null:
					hashMap.put(key, null);
					break;
				case Boolean:
					hashMap.put(key, readableMap.getBoolean(key));
					break;
				case Number:
					hashMap.put(key, readableMap.getDouble(key));
					break;
				case String:
					hashMap.put(key, readableMap.getString(key));
					break;
				case Array:
					hashMap.put(key, toArray(readableMap.getArray(key)));
				case Map:
					hashMap.put(key, toMap(readableMap.getMap(key)));
				default:
					throw new IllegalArgumentException("Could not convert object with key: " + key + ".");
			}
		}

		return hashMap;
	}

	// taken from // https://github.com/facebook/react-native/blob/master/ReactAndroid/src/main/java/com/facebook/react/bridge/ReadableNativeArray.java
	// with slight modification
	private static Collection<Object> toArray(ReadableArray readableArray) {
		List<Object> arrayList = new ArrayList<>();
		for (int i = 0; i < readableArray.size(); i++) {
			switch (readableArray.getType(i)) {
				case Null:
					arrayList.add(null);
					break;
				case Boolean:
					arrayList.add(readableArray.getBoolean(i));
					break;
				case Number:
					arrayList.add(readableArray.getDouble(i));
					break;
				case String:
					arrayList.add(readableArray.getString(i));
					break;
				case Map:
					arrayList.add(toMap(readableArray.getMap(i)));
					break;
				case Array:
					arrayList.add(toArray(readableArray.getArray(i)));
					break;
				default:
					throw new IllegalArgumentException("Could not convert object at index: " + i + ".");
			}
		}

		return arrayList;
	}
}
